==> qucs-0.0.6.tar.gz: qucs-0.0.6/qucs-core/src/converter/tokens_spice.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TitleLine = 258,
     InvalidCharacter = 259,
     End = 260,
     Eol = 261,
     Identifier = 262,
     Digits = 263,
     Floats = 264,
     Nodes = 265,
     Options = 266,
     Function = 267,
     SUBCKT_Action = 268,
     ENDS_Action = 269,
     AC_Action = 270,
     OP_Action = 271,
     I_Source = 272,
     SAVE_Action = 273,
     RLC_Device = 274,
     L_Device = 275,
     K_Device = 276,
     IV_Source = 277,
     GE_Source = 278,
     FH_Source = 279,
     V_Source = 280,
     Diode_Device = 281,
     Bipolar_Device = 282,
     JFET_Device = 283,
     MOSFET_Device = 284,
     MESFET_Device = 285,
     MODEL_Action = 286,
     MODEL_Spec = 287,
     TRAN_Action = 288,
     PLOT_Action = 289,
     VoltFunc = 290,
     CurrFunc = 291,
     DC_Action = 292,
     PRINT_Action = 293,
     OPTIONS_Action = 294,
     WIDTH_Action = 295,
     NOISE_Action = 296,
     PZ_Action = 297,
     CurVol = 298,
     PoleZero = 299,
     ALL_Special = 300,
     X_Device = 301,
     O_Device = 302,
     ModelProps = 303,
     OFF_Special = 304,
     IC_Special = 305,
     SIM_Type = 306,
     TEMP_Special = 307,
     MOS_Special = 308,
     B_Source = 309,
     DISTO_Action = 310,
     INCLUDE_Action = 311,
     File = 312,
     BranchFunc = 313,
     NODESET_Action = 314,
     T_Device = 315,
     U_Device = 316,
     S_Device = 317,
     W_Device = 318,
     ON_Special = 319,
     TF_Action = 320,
     SENS_Action = 321,
     FOUR_Action = 322,
     OpFunc = 323
   };
#endif
#define TitleLine 258
#define InvalidCharacter 259
#define End 260
#define Eol 261
#define Identifier 262
#define Digits 263
#define Floats 264
#define Nodes 265
#define Options 266
#define Function 267
#define SUBCKT_Action 268
#define ENDS_Action 269
#define AC_Action 270
#define OP_Action 271
#define I_Source 272
#define SAVE_Action 273
#define RLC_Device 274
#define L_Device 275
#define K_Device 276
#define IV_Source 277
#define GE_Source 278
#define FH_Source 279
#define V_Source 280
#define Diode_Device 281
#define Bipolar_Device 282
#define JFET_Device 283
#define MOSFET_Device 284
#define MESFET_Device 285
#define MODEL_Action 286
#define MODEL_Spec 287
#define TRAN_Action 288
#define PLOT_Action 289
#define VoltFunc 290
#define CurrFunc 291
#define DC_Action 292
#define PRINT_Action 293
#define OPTIONS_Action 294
#define WIDTH_Action 295
#define NOISE_Action 296
#define PZ_Action 297
#define CurVol 298
#define PoleZero 299
#define ALL_Special 300
#define X_Device 301
#define O_Device 302
#define ModelProps 303
#define OFF_Special 304
#define IC_Special 305
#define SIM_Type 306
#define TEMP_Special 307
#define MOS_Special 308
#define B_Source 309
#define DISTO_Action 310
#define INCLUDE_Action 311
#define File 312
#define BranchFunc 313
#define NODESET_Action 314
#define T_Device 315
#define U_Device 316
#define S_Device 317
#define W_Device 318
#define ON_Special 319
#define TF_Action 320
#define SENS_Action 321
#define FOUR_Action 322
#define OpFunc 323




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 140 "parse_spice.y"
typedef union YYSTYPE {
  char * ident;
  char * str;
  double d;
  struct definition_t * definition;
  struct definition_t * subcircuit;
  struct value_t * value;
} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 182 "tokens_spice.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE spice_lval;

==> qucs-0.0.8.tar.gz: qucs-0.0.8/qucs-core/src/converter/tokens_spice.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TitleLine = 258,
     InvalidCharacter = 259,
     End = 260,
     Eol = 261,
     Identifier = 262,
     Digits = 263,
     Floats = 264,
     Nodes = 265,
     Options = 266,
     Function = 267,
     SUBCKT_Action = 268,
     ENDS_Action = 269,
     AC_Action = 270,
     OP_Action = 271,
     I_Source = 272,
     SAVE_Action = 273,
     RLC_Device = 274,
     L_Device = 275,
     K_Device = 276,
     IV_Source = 277,
     GE_Source = 278,
     FH_Source = 279,
     V_Source = 280,
     Diode_Device = 281,
     Bipolar_Device = 282,
     JFET_Device = 283,
     MOSFET_Device = 284,
     MESFET_Device = 285,
     MODEL_Action = 286,
     MODEL_Spec = 287,
     TRAN_Action = 288,
     PLOT_Action = 289,
     VoltFunc = 290,
     CurrFunc = 291,
     DC_Action = 292,
     PRINT_Action = 293,
     OPTIONS_Action = 294,
     WIDTH_Action = 295,
     NOISE_Action = 296,
     PZ_Action = 297,
     CurVol = 298,
     PoleZero = 299,
     ALL_Special = 300,
     X_Device = 301,
     O_Device = 302,
     ModelProps = 303,
     OFF_Special = 304,
     IC_Special = 305,
     SIM_Type = 306,
     TEMP_Special = 307,
     MOS_Special = 308,
     B_Source = 309,
     DISTO_Action = 310,
     INCLUDE_Action = 311,
     File = 312,
     BranchFunc = 313,
     NODESET_Action = 314,
     T_Device = 315,
     U_Device = 316,
     S_Device = 317,
     W_Device = 318,
     ON_Special = 319,
     TF_Action = 320,
     SENS_Action = 321,
     FOUR_Action = 322,
     OpFunc = 323
   };
#endif
/* Tokens.  */
#define TitleLine 258
#define InvalidCharacter 259
#define End 260
#define Eol 261
#define Identifier 262
#define Digits 263
#define Floats 264
#define Nodes 265
#define Options 266
#define Function 267
#define SUBCKT_Action 268
#define ENDS_Action 269
#define AC_Action 270
#define OP_Action 271
#define I_Source 272
#define SAVE_Action 273
#define RLC_Device 274
#define L_Device 275
#define K_Device 276
#define IV_Source 277
#define GE_Source 278
#define FH_Source 279
#define V_Source 280
#define Diode_Device 281
#define Bipolar_Device 282
#define JFET_Device 283
#define MOSFET_Device 284
#define MESFET_Device 285
#define MODEL_Action 286
#define MODEL_Spec 287
#define TRAN_Action 288
#define PLOT_Action 289
#define VoltFunc 290
#define CurrFunc 291
#define DC_Action 292
#define PRINT_Action 293
#define OPTIONS_Action 294
#define WIDTH_Action 295
#define NOISE_Action 296
#define PZ_Action 297
#define CurVol 298
#define PoleZero 299
#define ALL_Special 300
#define X_Device 301
#define O_Device 302
#define ModelProps 303
#define OFF_Special 304
#define IC_Special 305
#define SIM_Type 306
#define TEMP_Special 307
#define MOS_Special 308
#define B_Source 309
#define DISTO_Action 310
#define INCLUDE_Action 311
#define File 312
#define BranchFunc 313
#define NODESET_Action 314
#define T_Device 315
#define U_Device 316
#define S_Device 317
#define W_Device 318
#define ON_Special 319
#define TF_Action 320
#define SENS_Action 321
#define FOUR_Action 322
#define OpFunc 323




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 140 "parse_spice.y"
typedef union YYSTYPE {
  char * ident;
  char * str;
  double d;
  struct definition_t * definition;
  struct definition_t * subcircuit;
  struct value_t * value;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 183 "tokens_spice.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE spice_lval;
